@@ -12,7 +12,7 @@ import os
 here = os.path.abspath(os.path.dirname(__file__))
 executable_file = os.path.dirname(here) + "/treeplotter/package_installer.zsh"
 
-def run(install=False):
+def run(install=False, force=False):
 	"""
 	Installation assistant for the treeplotter library.
 	"""
@@ -20,6 +20,9 @@ def run(install=False):
 	if install:
 		subprocess.run("echo Updating brew and installing requirements...", shell=True)
 		subprocess.run(["chmod", "+x", executable_file])
-		subprocess.run([executable_file])
+		if force:
+			os.system(executable_file + " forced")  # subprocess didn't work here...
+		else:
+			os.system(executable_file + " unforced")
 	else:
 		subprocess.run("echo Exiting", shell=True)
\ No newline at end of file
